API Documentation
=================

specviz.core
------------

.. automodapi:: specviz.core.hub
   :no-inheritance-diagram:

.. automodapi:: specviz.core.items
   :no-inheritance-diagram:

.. automodapi:: specviz.core.models
   :no-inheritance-diagram:

.. automodapi:: specviz.core.plugin
   :no-inheritance-diagram:

specviz.plugins
---------------

.. automodapi:: specviz.plugins.arithmetic
   :no-inheritance-diagram:

.. The following raises a warning that needs to be addressed before we can
.. add it back.
.. .. automodapi:: specviz.plugins.loader_wizard
..    :no-inheritance-diagram:

.. automodapi:: specviz.plugins.model_editor
   :no-inheritance-diagram:

.. automodapi:: specviz.plugins.smoothing
   :no-inheritance-diagram:

.. automodapi:: specviz.plugins.statistics
   :no-inheritance-diagram:

.. automodapi:: specviz.plugins.unit_change
   :no-inheritance-diagram:

.. automodapi:: specviz.plugins.line_labels
   :no-inheritance-diagram:


specviz.utils
-------------

.. automodapi:: specviz.utils.helper_functions
   :no-inheritance-diagram:

specviz.widgets
---------------

.. automodapi:: specviz.widgets.custom
   :no-inheritance-diagram:

.. automodapi:: specviz.widgets.delegates
   :no-inheritance-diagram:

.. automodapi:: specviz.widgets.plotting
   :no-inheritance-diagram:

.. automodapi:: specviz.widgets.workspace
   :no-inheritance-diagram:
